==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/cn.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: cn.php,v 1.12 2005/12/07 15:02:11 bigmichi1 Exp $

$charset                = 'gb2312';

$text['title']          = 'ϵͳϢ';
$text['vitals']         = 'ϵͳҪϢ';
$text['hostname']       = '';
$text['ip']             = 'IP';
$text['kversion']       = 'ں˰汾';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'ʱ';
$text['users']          = 'ʹ';
$text['loadavg']        = 'ƽ';

$text['hardware']       = 'ӲϢ';
$text['numcpu']         = '';
$text['cpumodel']       = 'CPUͺ';
$text['cpuspeed']       = 'оƬٶ';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'CacheС';
$text['bogomips']       = 'ϵͳBogomips';

$text['pci']            = 'PCI豸';
$text['ide']            = 'IDE豸';
$text['scsi']           = 'SCSI豸';
$text['usb']            = 'USB豸';

$text['netusage']       = '縺';
$text['device']         = '豸';
$text['received']       = '';
$text['sent']           = 'ͳ';
$text['errors']         = '/ж';

$text['memusage']       = 'ڴʹ';
$text['phymem']         = 'ڴ';
$text['swap']           = 'ڴ()';

$text['fs']             = 'ѹط';
$text['mount']          = '·';
$text['partition']      = '';

$text['percent']        = 'ʹٷֱ';
$text['type']           = 'ļϵͳ';
$text['free']           = 'ʣռ';
$text['used']           = 'ÿռ';
$text['size']           = '';
$text['totals']         = 'ʹ';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = '';

$text['capacity']       = '';

$text['template']       = '';
$text['language']       = '';
$text['submit']         = 'ȷ';
$text['created']        = ' By';
$text['locale']         = 'zh_CN.eucCN';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = '';
$text['hours']          = 'Сʱ';
$text['minutes']        = '';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/cn.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: cn.php,v 1.15 2006/06/05 11:48:16 bigmichi1 Exp $

$charset                = 'gb2312';

$text['title']          = 'ϵͳϢ';
$text['vitals']         = 'ϵͳҪϢ';
$text['hostname']       = '';
$text['ip']             = 'IP';
$text['kversion']       = 'ں˰汾';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'ʱ';
$text['users']          = 'ʹ';
$text['loadavg']        = 'ƽ';

$text['hardware']       = 'ӲϢ';
$text['numcpu']         = '';
$text['cpumodel']       = 'CPUͺ';
$text['cpuspeed']       = 'оƬٶ';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'CacheС';
$text['bogomips']       = 'ϵͳBogomips';

$text['pci']            = 'PCI豸';
$text['ide']            = 'IDE豸';
$text['scsi']           = 'SCSI豸';
$text['usb']            = 'USB豸';

$text['netusage']       = '縺';
$text['device']         = '豸';
$text['received']       = '';
$text['sent']           = 'ͳ';
$text['errors']         = '/ж';

$text['memusage']       = 'ڴʹ';
$text['phymem']         = 'ڴ';
$text['swap']           = 'ڴ()';

$text['fs']             = 'ѹط';
$text['mount']          = '·';
$text['partition']      = '';

$text['percent']        = 'ʹٷֱ';
$text['type']           = 'ļϵͳ';
$text['free']           = 'ʣռ';
$text['used']           = 'ÿռ';
$text['size']           = '';
$text['totals']         = 'ʹ';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = '';

$text['capacity']       = '';

$text['template']       = '';
$text['language']       = '';
$text['submit']         = 'ȷ';
$text['created']        = ' By';
$text['locale']         = 'zh_CN.eucCN';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = '';
$text['hours']          = 'Сʱ';
$text['minutes']        = '';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']    = 'Established Network Connections';
?>
